@@ -69,6 +69,10 @@ cppa3_content_model = {
                             cppa('Splitting'),
                             cppa('AlternateChannel')],
 
+    cppa('PullHandling') : [cppa('PullChannelId')],
+
+    cppa('Compression') : [cppa('CompressionAlgorithm')],
+
     cppa('WSSecurityBinding') : [ cppa('WSSVersion'),
                                   cppa('SecurityPolicy'),
                                   cppa('SAMLKeyConfirmedSubjectToken'),
@@ -76,6 +80,12 @@ cppa3_content_model = {
                                   cppa('Encryption'),
                                   cppa('UserAuthentication')],
 
+    cppa('UserAuthentication') : [ cppa('Username'),
+                                   cppa('Password'),
+                                   cppa('Digest'),
+                                   cppa('Nonce'),
+                                   cppa('Created')],
+
     cppa('AS4ReceptionAwareness') : [ cppa('DuplicateHandling'),
                                       cppa('RetryHandling') ],
 
@@ -108,6 +118,11 @@ cppa3_content_model = {
                            cppa('EncryptionTrustAnchorSetRef'),
                            cppa('EncryptionCertificatePolicySetRef')],
 
+    cppa('KeyEncryption') : [ cppa('EncryptionAlgorithm'),
+                              cppa('MaskGenerationFunction'),
+                              cppa('DigestAlgorithm')],
+
+
     cppa('DataEncryption') : [ cppa('EncryptionAlgorithm'),
                                cppa('EncryptElements'),
                                cppa('EncryptAttachments'),
